@@ -1,24 +1,30 @@
-from django_jalali import forms as jforms
-from django.utils.translation import ugettext as _
 from django import forms
 from django.contrib.admin.widgets import AdminTimeWidget
 from django.utils.safestring import mark_safe
+from django.utils.translation import gettext as _
+
+from django_jalali import forms as jforms
+from django_jalali.settings import jalali_settings
 
-import settings
 
 class AdminjDateWidget(jforms.jDateInput):
-    class Media:
-        js = (settings.ADMIN_MEDIA_PREFIX + "js/jcalendar.js",
-            settings.ADMIN_MEDIA_PREFIX + "js/admin/jDateTimeShortcuts.js")
-    def __init__(self, attrs={}, format=None):
-        super(AdminjDateWidget, self).__init__(attrs={'class': 'vjDateField', 'size': '10'}, format=format)
 
+    class Media:
+        js = jalali_settings.ADMIN_JS_STATIC_FILES
+        css = jalali_settings.ADMIN_CSS_STATIC_FILES
+
+    def __init__(self, attrs=None, format=None):
+        final_attrs = {"class": "vjDateField", "size": "10"}
+        if attrs is not None:
+            final_attrs.update(attrs)
+        super().__init__(attrs=final_attrs, format=format)
 
 
 class AdminSplitjDateTime(forms.SplitDateTimeWidget):
     """
     A SplitDateTime Widget that has some admin-specific styling.
     """
+
     def __init__(self, attrs=None):
         widgets = [AdminjDateWidget, AdminTimeWidget]
         # Note that we're calling MultiWidget, not SplitDateTimeWidget, because
@@ -26,5 +32,12 @@ class AdminSplitjDateTime(forms.SplitDateTimeWidget):
         forms.MultiWidget.__init__(self, widgets, attrs)
 
     def format_output(self, rendered_widgets):
-        return mark_safe(u'<p class="datetime">%s %s<br />%s %s</p>' % \
-            (_('Date:'), rendered_widgets[0], _('Time:'), rendered_widgets[1]))
+        return mark_safe(
+            '<p class="datetime">%s %s<br />%s %s</p>'
+            % (
+                _("Date:"),
+                rendered_widgets[0],
+                _("Time:"),
+                rendered_widgets[1],
+            )
+        )
